From 90d1f1cecb6a51297b4ee189fa2e1385ae3f238a Mon Sep 17 00:00:00 2001
From: Peter Penchev <openstack-dev@storpool.com>
Date: Thu, 29 Aug 2019 22:39:06 +0300
Subject: [PATCH] Allow for thin provisioning in the allocation test.

On Cinder backends that support thin provisioning, the amount of space
allocated after creating an empty volume may be less than the volume
size.

Change-Id: If90ea675fd28007dc4d67c8254e4cdee4c4e97bc
---
 cinderlib/tests/functional/test_basic.py | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/cinderlib/tests/functional/test_basic.py b/cinderlib/tests/functional/test_basic.py
index e65f994..a905164 100644
--- a/cinderlib/tests/functional/test_basic.py
+++ b/cinderlib/tests/functional/test_basic.py
@@ -14,6 +14,7 @@
 #    under the License.
 
 import os
+import sys  # RDBG
 
 import base_tests
 import cinderlib
@@ -72,7 +73,9 @@ class BackendFunctBasic(base_tests.BaseFunctTestCase):
         new_size = sum(p.get('allocated_capacity_gb',
                              p.get('provisioned_capacity_gb', vol.size))
                        for p in new_pools_info)
-        self.assertEqual(initial_size + vol.size, new_size)
+        print(f'RDBG initial_size {initial_size} new_size {new_size} vol size {vol.size}', file=sys.stderr)
+        if not any(p.get('thin_provisioning_support') for p in new_pools_info):
+            self.assertEqual(initial_size + vol.size, new_size)
 
     def test_create_volume(self):
         vol = self._create_vol(self.backend)
-- 
2.23.0

